@@ -256,6 +256,13 @@ class TestFlow:
 
         assert simple_flow.state == FlowState.STOPPED
 
+    async def test_cancelled_process_reraises_cancelled_error(self, slow_simple_flow, task):
+        with pytest.raises(asyncio.CancelledError):
+            future = asyncio.ensure_future(slow_simple_flow.process(task))
+            await asyncio.sleep(0.1)
+            future.cancel()
+            await future
+
     async def test_stop_finish_task_on_graceful(self, sleep_handlers, simple_flow, task):
         """Checks that task will be processed to the end after Flow stop command with graceful mode."""
         t = asyncio.ensure_future(simple_flow.process(task))
@@ -287,10 +294,10 @@ class TestFlow:
 
     async def test_process_performance_with_batching(self, flow_with_batch_handler, tasks_batch):
         """Checks that all tasks will be processed on time with batch handler."""
-        await asyncio.wait_for(
-            process_tasks(flow_with_batch_handler, tasks_batch),
-            timeout=CatDetector.BATCH_PROCESS_TIME,
-        )
+        t0 = time.time()
+        await process_tasks(flow_with_batch_handler, tasks_batch),
+        t1 = time.time()
+        assert pytest.approx(t1 - t0, 0.2) == CatDetector.BATCH_PROCESS_TIME
         assert all(task.result for task in tasks_batch)
 
     async def test_process_performance_with_dynamic_batching(self, flow_with_dynamic_batch_handler, tasks_batch):
